"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFocusRing = exports.focusRing = void 0;
const tokens_1 = require("@leafygreen-ui/tokens");
const emotion_1 = require("@leafygreen-ui/emotion");
const palette_1 = require("@leafygreen-ui/palette");
const react_1 = require("react");
const use_theme_1 = require("./use-theme");
const focusRingStyles = (0, emotion_1.css)({
    position: 'relative',
    outline: 'none',
    '&::after': {
        position: 'absolute',
        content: '""',
        pointerEvents: 'none',
        top: 3,
        right: 3,
        bottom: 3,
        left: 3,
        borderRadius: tokens_1.spacing[100],
        boxShadow: `0 0 0 0 transparent`,
        transition: 'box-shadow .16s ease-in',
        zIndex: 1,
    },
});
const focusRingVisibleStyles = (0, emotion_1.css)({
    '&::after': {
        boxShadow: `0 0 0 3px ${palette_1.palette.blue.light1} !important`,
        transitionTimingFunction: 'ease-out',
    },
});
const focusRingHoverVisibleStyles = (darkMode) => (0, emotion_1.css)({
    '&::after': {
        boxShadow: `0 0 0 3px ${darkMode ? palette_1.palette.gray.dark2 : palette_1.palette.gray.light2}`,
        transitionTimingFunction: 'ease-out',
    },
});
/**
 * Default focus ring styles. Can be used for simple cases where we want the
 * default ring with no customization at all (most of the cases in Compass)
 */
exports.focusRing = (0, emotion_1.css)(focusRingStyles, {
    // It's important that we only show focus ring when the focus is determined by
    // the browser as "visible". This means that e.g., buttons will only get the
    // ring around them when navigating application with a keyboard and not just
    // clicking a button which can be annoying
    //
    // https://developer.mozilla.org/en-US/docs/Web/CSS/:focus-visible
    '&:focus-visible': focusRingVisibleStyles,
});
const focusRingOuter = (0, emotion_1.css)({
    '&::after': {
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
    },
});
const focusRingWithin = (0, emotion_1.css)({
    '&:focus-within': focusRingVisibleStyles,
});
const focusRingHover = (darkMode) => (0, emotion_1.css)({
    '&:hover': focusRingHoverVisibleStyles(darkMode),
});
/**
 * Provides focus ring styles with a few additional options allowing to override
 * default style
 *
 * @param options
 * @param options.outer show focus ring outside the component (default: false)
 * @param options.focusWithin show focus ring on focus within instead of focus visible (default: false)
 * @param options.hover show focus ring on hover in addition to focus (default: false)
 * @param options.radius focus ring radius (default: 4px or spacing[100] from leafygreen)
 * @returns props to apply to the component
 */
function useFocusRing({ outer = false, focusWithin = false, hover = false, radius, } = {}) {
    const darkMode = (0, use_theme_1.useDarkMode)();
    const outerClass = (0, react_1.useMemo)(() => {
        return outer && focusRingOuter;
    }, [outer]);
    const radiusClass = (0, react_1.useMemo)(() => {
        return (typeof radius === 'number' &&
            (0, emotion_1.css)({
                '&::after': {
                    borderRadius: radius,
                },
            }));
    }, [radius]);
    const focusWithinClass = (0, react_1.useMemo)(() => {
        return focusWithin && focusRingWithin;
    }, [focusWithin]);
    const hoverClass = (0, react_1.useMemo)(() => {
        return hover && focusRingHover(!!darkMode);
    }, [hover, darkMode]);
    return {
        className: (0, emotion_1.cx)(exports.focusRing, outerClass, radiusClass, focusWithinClass, hoverClass),
    };
}
exports.useFocusRing = useFocusRing;
//# sourceMappingURL=use-focus-ring.js.map