import React from 'react';
import type { ToastProps } from '../components/leafygreen';
export type ToastProperties = Pick<ToastProps, 'actionElement' | 'title' | 'description' | 'variant' | 'progress' | 'timeout' | 'dismissible' | 'onClose'>;
export interface ToastActions {
    openToast: (id: string, toastProperties: ToastProperties) => void;
    closeToast: (id: string) => void;
}
/**
 * Programmatically trigger a
 * [leafygreen Toast](https://www.mongodb.design/component/toast/code-docs)
 * component to appear on the screen. Can be used both inside and __outside__
 * React rendering tree. The latter is especially useful for triggering toast
 * showing up for any async business logic flow.
 *
 * @example
 * function insertDocumentAction() {
 *   dataService.insertOne(...).then(
 *     () => {
 *       openToast(
 *         `insert-doc-${ns}`,
 *         { variant: 'success', title: 'Successfully inserted document' }
 *       )
 *     },
 *     (err) => {
 *       openToast(
 *         `insert-doc-${ns}`,
 *         { variant: 'warning', title: 'Failed to insert document', description: err.message }
 *       )
 *     }
 *   )
 * }
 *
 * Same method can be used to update the content of the toast that is already
 * displayed
 *
 * @example
 * function insertManyDocuments() {
 *   let total = 0;
 *   for (const doc of docs) {
 *     await dataService.insertOne(doc);
 *     openToast(
 *       `insert-doc-${ns}`,
 *       { variant: 'progress', title: 'Inserting documents', progress: docs.length / ++total }
 *     )
 *   }
 * }
 *
 * @param id unique toast id that can be used to close the toast later
 * @param props Toast rendering properties
 */
export declare const openToast: (id: string, props: ToastProperties) => void;
/**
 * Programmatically close a toast with a matching id
 *
 * @param id unique toast id
 */
export declare const closeToast: (id: string) => void;
export declare const ToastArea: React.FunctionComponent;
//# sourceMappingURL=use-toast.d.ts.map